( cd boot ; rm -rf config )
( cd boot ; ln -sf config-generic-2.6.24.5 config )
( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-generic-2.6.24.5 System.map )
( cd boot ; rm -rf vmlinux )
( cd boot ; ln -sf vmlinux-generic-2.6.24.5 vmlinux )
